@@ -1,7 +1,7 @@
-"""Mirror files to online services"""
+"""Upload files to online mirroring services."""
 from mirror_ace import MirrorAceConnection  # noqa
 
 __author__ = """Mycsina"""
 __email__ = "mycsina@protonmail.com"
-__version__ = "0.1.2"
+__version__ = "0.1.4"
 APP_NAME = "mirror-up"
